// src/utils/useHCesiumViewerClsGroundStation.ts
import type { GroundStationOptions, HCesiumViewerCls } from '@/components/h-cesium-viewer/h-cesium-viewer-class';
import type { MaybeRefOrGetter } from 'vue';

/**
 * 管理 Cesium Viewer 中的地面站实体，根据选中的 ID 列表进行同步。
 * @param hCesiumViewerInst - HCesiumViewerCls 实例或其 getter。
 * @param groundStationList - 包含所有可用地面站选项的数组或 getter。
 * @param selectedStationIds - 包含当前选中地面站 ID 的数组或 getter。
 */
export function useHCesiumViewerClsGroundStation(
  hCesiumViewerInst: MaybeRefOrGetter<HCesiumViewerCls | null>,
  groundStationList: MaybeRefOrGetter<Array<GroundStationOptions> | undefined>,
  selectedStationIds: MaybeRefOrGetter<string[] | undefined>,
) {
  // 创建一个从 ID 到站点选项的映射，方便查找
  const stationMap = computed(() => {
    const map = new Map<string, GroundStationOptions>();
    const list = toValue(groundStationList) ?? [];
    for (const station of list) {
      map.set(station.id, station);
    }
    return map;
  });

  // watchEffect: 同步 selectedStationIds 到 Cesium 实体
  watchEffect(() => {
    const viewerInstance = toValue(hCesiumViewerInst);
    if (!viewerInstance) {
      // 如果 viewer 实例尚未初始化或已销毁，则不执行任何操作
      return;
    }

    const selectedIds = toValue(selectedStationIds) ?? [];
    const selectedIdsSet = new Set(selectedIds); // 需要显示的站点 ID
    const currentEntityIds = new Set(viewerInstance.currentStationEntities.keys()); // 当前已显示的站点 ID

    // 1. 移除不再选中的站点
    for (const entityId of currentEntityIds) {
      if (!selectedIdsSet.has(entityId)) {
        // 如果当前显示的实体不在新的选中列表里，则移除
        viewerInstance.removeGroundStationById(entityId);
      }
    }

    // 2. 添加新增的选中站点
    for (const selectedId of selectedIdsSet) {
      if (!currentEntityIds.has(selectedId)) {
        // 如果选中的 ID 对应的实体当前未显示，则添加
        const stationToAdd = stationMap.value.get(selectedId); // 从映射中查找站点信息
        if (stationToAdd) {
          viewerInstance.addGroundStation(stationToAdd);
        } else {
          // 如果在 groundStationList 中找不到对应的站点信息，发出警告
          consola.warn(`无法找到 ID 为 "${selectedId}" 的站点信息，无法添加到地图。`);
        }
      }
    }
  });

  // 返回 stationMap 可能在某些场景下有用，例如调试或扩展
  return {
    stationMap, // 可以考虑是否真的需要返回这个
  };
}
